@@ -1,18 +1,17 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
 
 import ipaddress
 import sys
 import unittest
-from unittest.mock import patch, MagicMock
+from unittest.mock import MagicMock, patch
 
 sys.path.append("..")
 
+import maxminddb
+
 import geoip2.database
 import geoip2.errors
-import maxminddb
 
 try:
     import maxminddb.extension
@@ -35,7 +34,7 @@ class TestReader(unittest.TestCase):
         reader = geoip2.database.Reader("tests/data/test-data/GeoIP2-City-Test.mmdb")
         with self.assertRaisesRegex(
             geoip2.errors.AddressNotFoundError,
-            "The address 10.10.10.10 is not in the " "database.",
+            "The address 10.10.10.10 is not in the database.",
         ):
             reader.city("10.10.10.10")
         reader.close()
@@ -48,7 +47,7 @@ class TestReader(unittest.TestCase):
         except geoip2.errors.AddressNotFoundError as e:
             self.assertEqual(e.network, ipaddress.ip_network("10.0.0.0/8"))
         except Exception as e:
-            self.fail(f"Expected AddressNotFoundError, got {type(e)}: {str(e)}")
+            self.fail(f"Expected AddressNotFoundError, got {type(e)}: {e!s}")
         finally:
             reader.close()
 
@@ -56,7 +55,7 @@ class TestReader(unittest.TestCase):
         reader = geoip2.database.Reader("tests/data/test-data/GeoIP2-City-Test.mmdb")
         with self.assertRaisesRegex(
             TypeError,
-            "The country method cannot be used with " "the GeoIP2-City database",
+            "The country method cannot be used with the GeoIP2-City database",
         ):
             reader.country("1.1.1.1")
         reader.close()
@@ -64,14 +63,15 @@ class TestReader(unittest.TestCase):
     def test_invalid_address(self) -> None:
         reader = geoip2.database.Reader("tests/data/test-data/GeoIP2-City-Test.mmdb")
         with self.assertRaisesRegex(
-            ValueError, "u?'invalid' does not appear to be an " "IPv4 or IPv6 address"
+            ValueError,
+            "u?'invalid' does not appear to be an IPv4 or IPv6 address",
         ):
             reader.city("invalid")
         reader.close()
 
     def test_anonymous_ip(self) -> None:
         reader = geoip2.database.Reader(
-            "tests/data/test-data/GeoIP2-Anonymous-IP-Test.mmdb"
+            "tests/data/test-data/GeoIP2-Anonymous-IP-Test.mmdb",
         )
         ip_address = "1.2.0.1"
 
@@ -82,13 +82,13 @@ class TestReader(unittest.TestCase):
         self.assertEqual(record.is_public_proxy, False)
         self.assertEqual(record.is_residential_proxy, False)
         self.assertEqual(record.is_tor_exit_node, False)
-        self.assertEqual(record.ip_address, ip_address)
+        self.assertEqual(record.ip_address, ipaddress.ip_address(ip_address))
         self.assertEqual(record.network, ipaddress.ip_network("1.2.0.0/16"))
         reader.close()
 
     def test_anonymous_ip_all_set(self) -> None:
         reader = geoip2.database.Reader(
-            "tests/data/test-data/GeoIP2-Anonymous-IP-Test.mmdb"
+            "tests/data/test-data/GeoIP2-Anonymous-IP-Test.mmdb",
         )
         ip_address = "81.2.69.1"
 
@@ -99,7 +99,7 @@ class TestReader(unittest.TestCase):
         self.assertEqual(record.is_public_proxy, True)
         self.assertEqual(record.is_residential_proxy, True)
         self.assertEqual(record.is_tor_exit_node, True)
-        self.assertEqual(record.ip_address, ip_address)
+        self.assertEqual(record.ip_address, ipaddress.ip_address(ip_address))
         self.assertEqual(record.network, ipaddress.ip_network("81.2.69.0/24"))
         reader.close()
 
@@ -113,7 +113,7 @@ class TestReader(unittest.TestCase):
 
         self.assertEqual(record.autonomous_system_number, 1221)
         self.assertEqual(record.autonomous_system_organization, "Telstra Pty Ltd")
-        self.assertEqual(record.ip_address, ip_address)
+        self.assertEqual(record.ip_address, ipaddress.ip_address(ip_address))
         self.assertEqual(record.network, ipaddress.ip_network("1.128.0.0/11"))
 
         self.assertRegex(
@@ -129,11 +129,15 @@ class TestReader(unittest.TestCase):
         record = reader.city("81.2.69.160")
 
         self.assertEqual(
-            record.country.name, "United Kingdom", "The default locale is en"
+            record.country.name,
+            "United Kingdom",
+            "The default locale is en",
         )
         self.assertEqual(record.country.is_in_european_union, False)
         self.assertEqual(
-            record.location.accuracy_radius, 100, "The accuracy_radius is populated"
+            record.location.accuracy_radius,
+            100,
+            "The accuracy_radius is populated",
         )
         self.assertEqual(record.registered_country.is_in_european_union, False)
         self.assertFalse(record.traits.is_anycast)
@@ -145,23 +149,25 @@ class TestReader(unittest.TestCase):
 
     def test_connection_type(self) -> None:
         reader = geoip2.database.Reader(
-            "tests/data/test-data/GeoIP2-Connection-Type-Test.mmdb"
+            "tests/data/test-data/GeoIP2-Connection-Type-Test.mmdb",
         )
         ip_address = "1.0.1.0"
 
         record = reader.connection_type(ip_address)
 
         self.assertEqual(
-            record, eval(repr(record)), "ConnectionType repr can be eval'd"
+            record,
+            eval(repr(record)),
+            "ConnectionType repr can be eval'd",
         )
 
         self.assertEqual(record.connection_type, "Cellular")
-        self.assertEqual(record.ip_address, ip_address)
+        self.assertEqual(record.ip_address, ipaddress.ip_address(ip_address))
         self.assertEqual(record.network, ipaddress.ip_network("1.0.1.0/24"))
 
         self.assertRegex(
             str(record),
-            r"ConnectionType\(\{.*Cellular.*\}\)",
+            r"ConnectionType\(.*Cellular.*\)",
             "ConnectionType str representation is reasonable",
         )
 
@@ -171,7 +177,9 @@ class TestReader(unittest.TestCase):
         reader = geoip2.database.Reader("tests/data/test-data/GeoIP2-Country-Test.mmdb")
         record = reader.country("81.2.69.160")
         self.assertEqual(
-            record.traits.ip_address, "81.2.69.160", "IP address is added to model"
+            record.traits.ip_address,
+            ipaddress.ip_address("81.2.69.160"),
+            "IP address is added to model",
         )
         self.assertEqual(record.traits.network, ipaddress.ip_network("81.2.69.160/27"))
         self.assertEqual(record.country.is_in_european_union, False)
@@ -192,12 +200,12 @@ class TestReader(unittest.TestCase):
         self.assertEqual(record, eval(repr(record)), "Domain repr can be eval'd")
 
         self.assertEqual(record.domain, "maxmind.com")
-        self.assertEqual(record.ip_address, ip_address)
+        self.assertEqual(record.ip_address, ipaddress.ip_address(ip_address))
         self.assertEqual(record.network, ipaddress.ip_network("1.2.0.0/16"))
 
         self.assertRegex(
             str(record),
-            r"Domain\(\{.*maxmind.com.*\}\)",
+            r"Domain\(.*maxmind.com.*\)",
             "Domain str representation is reasonable",
         )
 
@@ -205,7 +213,7 @@ class TestReader(unittest.TestCase):
 
     def test_enterprise(self) -> None:
         with geoip2.database.Reader(
-            "tests/data/test-data/GeoIP2-Enterprise-Test.mmdb"
+            "tests/data/test-data/GeoIP2-Enterprise-Test.mmdb",
         ) as reader:
             ip_address = "74.209.24.0"
             record = reader.enterprise(ip_address)
@@ -217,9 +225,10 @@ class TestReader(unittest.TestCase):
             self.assertEqual(record.registered_country.is_in_european_union, False)
             self.assertEqual(record.traits.connection_type, "Cable/DSL")
             self.assertTrue(record.traits.is_legitimate_proxy)
-            self.assertEqual(record.traits.ip_address, ip_address)
+            self.assertEqual(record.traits.ip_address, ipaddress.ip_address(ip_address))
             self.assertEqual(
-                record.traits.network, ipaddress.ip_network("74.209.16.0/20")
+                record.traits.network,
+                ipaddress.ip_network("74.209.16.0/20"),
             )
             self.assertFalse(record.traits.is_anycast)
 
@@ -232,7 +241,7 @@ class TestReader(unittest.TestCase):
 
     def test_isp(self) -> None:
         with geoip2.database.Reader(
-            "tests/data/test-data/GeoIP2-ISP-Test.mmdb"
+            "tests/data/test-data/GeoIP2-ISP-Test.mmdb",
         ) as reader:
             ip_address = "1.128.0.0"
             record = reader.isp(ip_address)
@@ -242,12 +251,12 @@ class TestReader(unittest.TestCase):
             self.assertEqual(record.autonomous_system_organization, "Telstra Pty Ltd")
             self.assertEqual(record.isp, "Telstra Internet")
             self.assertEqual(record.organization, "Telstra Internet")
-            self.assertEqual(record.ip_address, ip_address)
+            self.assertEqual(record.ip_address, ipaddress.ip_address(ip_address))
             self.assertEqual(record.network, ipaddress.ip_network("1.128.0.0/11"))
 
             self.assertRegex(
                 str(record),
-                r"ISP\(\{.*Telstra.*\}\)",
+                r"ISP\(.*Telstra.*\)",
                 "ISP str representation is reasonable",
             )
 
@@ -258,10 +267,13 @@ class TestReader(unittest.TestCase):
 
     def test_context_manager(self) -> None:
         with geoip2.database.Reader(
-            "tests/data/test-data/GeoIP2-Country-Test.mmdb"
+            "tests/data/test-data/GeoIP2-Country-Test.mmdb",
         ) as reader:
             record = reader.country("81.2.69.160")
-            self.assertEqual(record.traits.ip_address, "81.2.69.160")
+            self.assertEqual(
+                record.traits.ip_address,
+                ipaddress.ip_address("81.2.69.160"),
+            )
 
     @patch("maxminddb.open_database")
     def test_modes(self, mock_open) -> None:
@@ -271,5 +283,5 @@ class TestReader(unittest.TestCase):
         with geoip2.database.Reader(
             path,
             mode=geoip2.database.MODE_MMAP_EXT,
-        ) as reader:
+        ):
             mock_open.assert_called_once_with(path, geoip2.database.MODE_MMAP_EXT)
